==> haskell-foundation-0.0.26.1-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-foundation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 foundation
version:              0.0.26.1
visibility:           public
id:                   foundation-0.0.26.1-4foZMwfMI36HRBn4Ug9p81
key:                  foundation-0.0.26.1-4foZMwfMI36HRBn4Ug9p81
license:              BSD-3-Clause
copyright:
    2015-2017 Vincent Hanquez <vincent@snarc.org>, 2017- Foundation Maintainers

maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             https://github.com/haskell-foundation/foundation
synopsis:             Alternative prelude with batteries and no dependencies
description:
    A custom prelude with no dependencies apart from base.

    This package has the following goals:

    * provide a base like sets of modules that provide a consistent set of features and bugfixes across multiple versions of GHC (unlike base).

    * provide a better and more efficient prelude than base'\''s prelude.

    * be self-sufficient: no external dependencies apart from base.

    * provide better data-types: packed unicode string by default, arrays.

    * Better numerical classes that better represent mathematical thing (No more all-in-one Num).

    * Better I/O system with less Lazy IO

    * Usual partial functions distinguished through type system

category:             foundation
abi:                  94a7e6b39607138d34cca3959913ec59
exposed:              True
exposed-modules:
    Foundation Foundation.Array Foundation.Array.Internal
    Foundation.Bits Foundation.Check Foundation.Check.Main
    Foundation.Class.Bifunctor Foundation.Class.Storable
    Foundation.Collection Foundation.Conduit Foundation.Conduit.Textual
    Foundation.Exception Foundation.Foreign Foundation.Format.CSV
    Foundation.Hashing Foundation.IO Foundation.IO.FileMap
    Foundation.IO.Terminal Foundation.List.DList Foundation.List.ListN
    Foundation.Math.Trigonometry Foundation.Monad
    Foundation.Monad.Except Foundation.Monad.Reader
    Foundation.Monad.State Foundation.Network.IPv4
    Foundation.Network.IPv6 Foundation.Numerical Foundation.Parser
    Foundation.Primitive Foundation.Random Foundation.Strict
    Foundation.String Foundation.String.Builder Foundation.String.Read
    Foundation.System.Bindings Foundation.System.Bindings.Linux
    Foundation.System.Bindings.Posix
    Foundation.System.Bindings.PosixDef Foundation.System.Entropy
    Foundation.System.Info Foundation.Time.Bindings
    Foundation.Time.StopWatch Foundation.Time.Types Foundation.Timing
    Foundation.Timing.Main Foundation.Tuple.Nth Foundation.UUID
    Foundation.VFS Foundation.VFS.FilePath Foundation.VFS.Path
    Foundation.VFS.URI

hidden-modules:
    Foundation.Tuple Foundation.Hashing.FNV Foundation.Hashing.SipHash
    Foundation.Hashing.Hasher Foundation.Hashing.Hashable
    Foundation.Check.Gen Foundation.Check.Print
    Foundation.Check.Arbitrary Foundation.Check.Property
    Foundation.Check.Config Foundation.Check.Types
    Foundation.Collection.Buildable Foundation.Collection.List
    Foundation.Collection.Element Foundation.Collection.InnerFunctor
    Foundation.Collection.Collection Foundation.Collection.Copy
    Foundation.Collection.Sequential Foundation.Collection.Keyed
    Foundation.Collection.Indexed Foundation.Collection.Foldable
    Foundation.Collection.Mutable Foundation.Collection.Zippable
    Foundation.Collection.Mappable Foundation.Conduit.Internal
    Foundation.Format.CSV.Types Foundation.Format.CSV.Builder
    Foundation.Format.CSV.Parser Foundation.Numerical.Floating
    Foundation.IO.File Foundation.Monad.MonadIO
    Foundation.Monad.Exception Foundation.Monad.Transformer
    Foundation.Monad.Identity Foundation.Monad.Base
    Foundation.Random.Class Foundation.Random.DRG
    Foundation.Random.ChaChaDRG Foundation.Random.XorShift
    Foundation.Array.Chunked.Unboxed Foundation.Array.Bitmap
    Foundation.Foreign.Alloc Foundation.Foreign.MemoryMap
    Foundation.Foreign.MemoryMap.Types Foundation.Partial
    Foundation.System.Entropy.Common Foundation.System.Bindings.Network
    Foundation.System.Bindings.Time Foundation.System.Bindings.Hs
    Foundation.Foreign.MemoryMap.Posix Foundation.System.Entropy.Unix

import-dirs:          /usr/lib/ghc-9.0.1/site-local/foundation-0.0.26.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/foundation-0.0.26.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/foundation-0.0.26.1
hs-libraries:         HSfoundation-0.0.26.1-4foZMwfMI36HRBn4Ug9p81
depends:
    base-4.15.0.0 basement-0.0.12-F0MrM1QYXPfKTXgGX2bdqG ghc-prim-0.7.0

haddock-interfaces:   /usr/share/doc/haskell-foundation/html/foundation.haddock
haddock-html:         /usr/share/doc/haskell-foundation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-foundation-0.0.29-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-foundation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 foundation
version:              0.0.29
visibility:           public
id:                   foundation-0.0.29-6v8EBP96mC98RXKA0HlS6Y
key:                  foundation-0.0.29-6v8EBP96mC98RXKA0HlS6Y
license:              BSD-3-Clause
copyright:
    2015-2017 Vincent Hanquez <vincent@snarc.org>, 2017- Foundation Maintainers

maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             https://github.com/haskell-foundation/foundation
synopsis:             Alternative prelude with batteries and no dependencies
description:
    A custom prelude with no dependencies apart from base.

    This package has the following goals:

    * provide a base like sets of modules that provide a consistent set of features and bugfixes across multiple versions of GHC (unlike base).

    * provide a better and more efficient prelude than base'\''s prelude.

    * be self-sufficient: no external dependencies apart from base.

    * provide better data-types: packed unicode string by default, arrays.

    * Better numerical classes that better represent mathematical thing (No more all-in-one Num).

    * Better I/O system with less Lazy IO

    * Usual partial functions distinguished through type system

category:             foundation
abi:                  9aa6360ece9a70e3600221470c11d49d
exposed:              True
exposed-modules:
    Foundation Foundation.Array Foundation.Array.Internal
    Foundation.Bits Foundation.Check Foundation.Check.Main
    Foundation.Class.Bifunctor Foundation.Class.Storable
    Foundation.Collection Foundation.Conduit Foundation.Conduit.Textual
    Foundation.Exception Foundation.Foreign Foundation.Format.CSV
    Foundation.Hashing Foundation.IO Foundation.IO.FileMap
    Foundation.IO.Terminal Foundation.List.DList Foundation.List.ListN
    Foundation.Math.Trigonometry Foundation.Monad
    Foundation.Monad.Except Foundation.Monad.Reader
    Foundation.Monad.State Foundation.Network.IPv4
    Foundation.Network.IPv6 Foundation.Numerical Foundation.Parser
    Foundation.Primitive Foundation.Random Foundation.Strict
    Foundation.String Foundation.String.Builder Foundation.String.Read
    Foundation.System.Bindings Foundation.System.Bindings.Linux
    Foundation.System.Bindings.Posix
    Foundation.System.Bindings.PosixDef Foundation.System.Entropy
    Foundation.System.Info Foundation.Time.Bindings
    Foundation.Time.StopWatch Foundation.Time.Types Foundation.Timing
    Foundation.Timing.Main Foundation.Tuple.Nth Foundation.UUID
    Foundation.VFS Foundation.VFS.FilePath Foundation.VFS.Path
    Foundation.VFS.URI

hidden-modules:
    Foundation.Tuple Foundation.Hashing.FNV Foundation.Hashing.SipHash
    Foundation.Hashing.Hasher Foundation.Hashing.Hashable
    Foundation.Check.Gen Foundation.Check.Print
    Foundation.Check.Arbitrary Foundation.Check.Property
    Foundation.Check.Config Foundation.Check.Types
    Foundation.Collection.Buildable Foundation.Collection.List
    Foundation.Collection.Element Foundation.Collection.InnerFunctor
    Foundation.Collection.Collection Foundation.Collection.Copy
    Foundation.Collection.Sequential Foundation.Collection.Keyed
    Foundation.Collection.Indexed Foundation.Collection.Foldable
    Foundation.Collection.Mutable Foundation.Collection.Zippable
    Foundation.Collection.Mappable Foundation.Conduit.Internal
    Foundation.Format.CSV.Types Foundation.Format.CSV.Builder
    Foundation.Format.CSV.Parser Foundation.Numerical.Floating
    Foundation.IO.File Foundation.Monad.MonadIO
    Foundation.Monad.Exception Foundation.Monad.Transformer
    Foundation.Monad.Identity Foundation.Monad.Base
    Foundation.Random.Class Foundation.Random.DRG
    Foundation.Random.ChaChaDRG Foundation.Random.XorShift
    Foundation.Array.Chunked.Unboxed Foundation.Array.Bitmap
    Foundation.Foreign.Alloc Foundation.Foreign.MemoryMap
    Foundation.Foreign.MemoryMap.Types Foundation.Partial
    Foundation.System.Entropy.Common Foundation.System.Bindings.Network
    Foundation.System.Bindings.Time Foundation.System.Bindings.Hs
    Foundation.Foreign.MemoryMap.Posix Foundation.System.Entropy.Unix

import-dirs:          /usr/lib/ghc-9.0.2/site-local/foundation-0.0.29
library-dirs:         /usr/lib/ghc-9.0.2/site-local/foundation-0.0.29
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-foundation
hs-libraries:         HSfoundation-0.0.29-6v8EBP96mC98RXKA0HlS6Y
depends:
    base-4.15.1.0 basement-0.0.15-IvZTyCKoUdE3jMkDdiQhQ0 ghc-prim-0.7.0

haddock-interfaces:   /usr/share/doc/haskell-foundation/html/foundation.haddock
haddock-html:         /usr/share/doc/haskell-foundation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
